fabric-provision
================

``fabric-provision`` is a tiny wrapper around `Chef
Solo <http://wiki.opscode.com/display/chef/Chef+Solo>`_. Use it for easy
provisioning right out of your ``fabfile.py``.

Have a look at the
`documentation <http://fabric-provision.readthedocs.org>`_.
